Immunogenicity Utilities is the package for HLA and Immunogenicity computing with Python.

It provides:

- low-to-high conversion

- calculation of Type 1 and Type II AMS, EMS, and HMS

    - both with DQ and without
    - both with ABO consideration and without
- useful eplet functions
- and much more
